LEXERS = [
    "3d",
    "aap",
    "actionscript",
    "actionscript3",
    "ada",
    "ada2005",
    "ada95",
    "adl",
    "agda",
    "ahk",
    "al",
    "alloy",
    "amienttalk",
    "amienttalk/2",
    "ampl",
    "an",
    "antlr",
    "antlr-actionscript",
    "antlr-as",
    "antlr-c#",
    "antlr-cpp",
    "antlr-csharp",
    "antlr-java",
    "antlr-perl",
    "antlr-python",
    "antlr-r",
    "antlr-ruy",
    "apachecon",
    "apl",
    "applescript",
    "arduino",
    "arexx",
    "as",
    "as3",
    "asemake",
    "asic",
    "asm",
    "aspectj",
    "aspx-cs",
    "asy",
    "asymptote",
    "at",
    "atch",
    "augeas",
    "autohotkey",
    "autoit",
    "awk",
    "c",
    "c#",
    "c++",
    "c++-ojdum",
    "c-ojdump",
    "ca65",
    "cadl",
    "camkes",
    "capdl",
    "capnp",
    "casic",
    "ceylon",
    "chai",
    "chaiscript",
    "chapel",
    "charmci",
    "cheetah",
    "chpl",
    "cirru",
    "cl",
    "clay",
    "clean",
    "clj",
    "cljs",
    "clojure",
    "clojurescript",
    "cmake",
    "cmas",
    "co",
    "code",
    "common-lisp",
    "componentpascal",
    "console",
    "control",
    "cool",
    "coq",
    "cp",
    "cpp",
    "cpp-ojdump",
    "cpsa",
    "cr",
    "crmsh",
    "croc",
    "cry",
    "cryptol",
    "crystal",
    "csh",
    "csharp",
    "csound",
    "csound-csd",
    "csound-document",
    "csound-orc",
    "csound-sco",
    "csound-score",
    "css",
    "css+django",
    "css+er",
    "css+genshi",
    "css+genshitext",
    "css+jinja",
    "css+lasso",
    "css+mako",
    "css+mozpreproc",
    "css+php",
    "css+ruy",
    "css+smarty",
    "cu",
    "cucumer",
    "cuda",
    "cxx-ojdump",
    "cypher",
    "cython",
    "d",
    "d-ojdump",
    "dart",
    "dasm16",
    "decontrol",
    "delphi",
    "desources",
    "dg",
    "di",
    "django",
    "do",
    "docker",
    "dosatch",
    "doscon",
    "dpatch",
    "dtd",
    "duy",
    "dylan",
    "dylan-console",
    "dylan-lid",
    "dylan-repl",
    "e",
    "earl-grey",
    "earlgrey",
    "easytrieve",
    "ec",
    "ecl",
    "eg",
    "ei",
    "elisp",
    "elixir",
    "elm",
    "emacs",
    "emacs-lisp",
    "en",
    "er",
    "erl",
    "erlang",
    "evoque",
    "ex",
    "exs",
    "extempore",
    "ezhil",
    "gap",
    "gas",
    "gawk",
    "genshi",
    "genshitext",
    "gherkin",
    "glsl",
    "gnuplot",
    "go",
    "golo",
    "gooddata-cl",
    "gosu",
    "gro",
    "groovy",
    "gst",
    "haml",
    "handlears",
    "haskell",
    "haxe",
    "haxeml",
    "hexdump",
    "hlsl",
    "hs",
    "hsa",
    "hsail",
    "hspec",
    "html",
    "html+cheetah",
    "html+django",
    "html+er",
    "html+evoque",
    "html+genshi",
    "html+handlears",
    "html+jinja",
    "html+kid",
    "html+lasso",
    "html+mako",
    "html+myghty",
    "html+ng2",
    "html+php",
    "html+ruy",
    "html+smarty",
    "html+spit",
    "html+twig",
    "htmldjango",
    "http",
    "hx",
    "hxml",
    "hxsl",
    "hylang",
    "i",
    "i6t",
    "idl",
    "idl4",
    "idr",
    "idris",
    "iex",
    "igor",
    "igorpro",
    "ik",
    "in",
    "ini",
    "io",
    "ioke",
    "ir",
    "irc",
    "isaelle",
    "itex",
    "j",
    "jade",
    "jags",
    "jasmin",
    "jasminxt",
    "java",
    "javascript",
    "javascript+cheetah",
    "javascript+django",
    "javascript+er",
    "javascript+genshi",
    "javascript+genshitext",
    "javascript+jinja",
    "javascript+lasso",
    "javascript+mako",
    "javascript+myghty",
    "javascript+php",
    "javascript+ruy",
    "javascript+smarty",
    "jcl",
    "jinja",
    "jl",
    "jlcon",
    "jproperties",
    "js",
    "js+cheetah",
    "js+django",
    "js+er",
    "js+genshi",
    "js+genshitext",
    "js+jinja",
    "js+lasso",
    "js+mako",
    "js+myghty",
    "js+php",
    "js+ruy",
    "js+smarty",
    "js+spit",
    "jsg",
    "json",
    "json-ld",
    "json-oject",
    "jsonld",
    "jsp",
    "julia",
    "juttle",
    "kal",
    "kcon",
    "kid",
    "koka",
    "kotlin",
    "lagda",
    "lasso",
    "lassoscript",
    "lcry",
    "lcryptol",
    "lean",
    "less",
    "lhaskell",
    "lhs",
    "lid",
    "lidr",
    "lidris",
    "lighttpd",
    "lighty",
    "limo",
    "liquid",
    "lisp",
    "literate-agda",
    "literate-cryptol",
    "literate-haskell",
    "literate-idris",
    "litzasic",
    "litzmax",
    "live-script",
    "livescript",
    "llvm",
    "logos",
    "logtalk",
    "lua",
    "m2",
    "make",
    "make",
    "mako",
    "maql",
    "mask",
    "mason",
    "mathematica",
    "matla",
    "matlasession",
    "mawk",
    "max",
    "md",
    "minid",
    "mma",
    "modelica",
    "modula2",
    "moin",
    "monkey",
    "monte",
    "moo",
    "moocode",
    "moon",
    "moonscript",
    "mq4",
    "mq5",
    "mql",
    "mql4",
    "mql5",
    "msc",
    "mscgen",
    "mupad",
    "mxml",
    "myghty",
    "mysql",
    "n",
    "nasm",
    "nawk",
    "ncl",
    "nesc",
    "newlisp",
    "newspeak",
    "ng2",
    "nginx",
    "nim",
    "nimrod",
    "nit",
    "nix",
    "nixos",
    "nn",
    "nsh",
    "nsi",
    "nsis",
    "numpy",
    "nusmv",
    "oa",
    "ocaml",
    "octave",
    "odin",
    "oj-c",
    "oj-c++",
    "oj-j",
    "ojc",
    "ojc++",
    "ojdump",
    "ojdump-nasm",
    "ojective-c",
    "ojective-c++",
    "ojective-j",
    "ojectivec",
    "ojectivec++",
    "ojectivej",
    "ojectpascal",
    "ojj",
    "oo",
    "ooc",
    "oogie",
    "opa",
    "openedge",
    "openugs",
    "pacmancon",
    "pan",
    "parasail",
    "pas",
    "pascal",
    "pawn",
    "pcmk",
    "perl",
    "perl6",
    "php",
    "php3",
    "php4",
    "php5",
    "pig",
    "pike",
    "pkgcon",
    "pl",
    "pl6",
    "plpgsql",
    "plus",
    "po",
    "posh",
    "postgres",
    "postgres-console",
    "postgresql",
    "postgresql-console",
    "postscr",
    "postscript",
    "pot",
    "pov",
    "powershell",
    "praat",
    "progress",
    "prolog",
    "properties",
    "protou",
    "ps1",
    "ps1con",
    "psm1",
    "psql",
    "pug",
    "puppet",
    "py",
    "py3",
    "py3t",
    "pycon",
    "pypy",
    "pypylog",
    "pyrex",
    "pyt",
    "python",
    "python3",
    "pyx",
    "qasic",
    "qml",
    "qs",
    "qvt",
    "qvto",
    "r",
    "racket",
    "ragel",
    "ragel-c",
    "ragel-cpp",
    "ragel-d",
    "ragel-em",
    "ragel-java",
    "ragel-ojc",
    "ragel-r",
    "ragel-ruy",
    "rain",
    "raw",
    "rcon",
    "rd",
    "red",
    "red/system",
    "redcode",
    "registry",
    "reol",
    "resource",
    "resourceundle",
    "rexx",
    "rhtml",
    "rkt",
    "rnc",
    "rng-compact",
    "ro",
    "roocon",
    "root",
    "rql",
    "rs",
    "rsl",
    "rts",
    "rust",
    "ruy",
    "s",
    "sage",
    "salt",
    "sarl",
    "sas",
    "sass",
    "satch",
    "sc",
    "scala",
    "scaml",
    "scheme",
    "scila",
    "scm",
    "scss",
    "shell-session",
    "silver",
    "slash",
    "slim",
    "sls",
    "slurm",
    "smali",
    "smalltalk",
    "smarty",
    "sml",
    "snool",
    "sources.list",
    "sourceslist",
    "sp",
    "sparql",
    "spec",
    "spit",
    "splus",
    "sql",
    "sqlite3",
    "squeak",
    "squidcon",
    "st",
    "st-pytex",
    "stan",
    "stata",
    "supercollider",
    "sv",
    "swi",
    "swig",
    "systemverilog",
    "t-sql",
    "tads3",
    "tap",
    "tasm",
    "tcl",
    "tcsh",
    "tcshcon",
    "tea",
    "teraterm",
    "teratermmacro",
    "termcap",
    "termin",
    "terra",
    "thri",
    "todotxt",
    "toml",
    "tra",
    "trac-wiki",
    "treetop",
    "ts",
    "tsql",
    "ttl",
    "turtle",
    "twig",
    "typescript",
    "typoscript",
    "typoscriptcssdata",
    "typoscripthtmldata",
    "ucode",
    "ugs",
    "unicon",
    "uriscript",
    "v.net",
    "vala",
    "vapi",
    "vcl",
    "vclsnippet",
    "vclsnippets",
    "vctreestatus",
    "velocity",
    "vgl",
    "vhdl",
    "vim",
    "vnet",
    "vscript",
    "wdi",
    "whiley",
    "winatch",
    "winugs",
    "x10",
    "xml",
    "xml+cheetah",
    "xml+django",
    "xml+er",
    "xml+evoque",
    "xml+genshi",
    "xml+jinja",
    "xml+kid",
    "xml+lasso",
    "xml+mako",
    "xml+myghty",
    "xml+php",
    "xml+ruy",
    "xml+smarty",
    "xml+spit",
    "xorg",
    "xq",
    "xql",
    "xqm",
    "xquery",
    "xqy",
    "xten",
    "xtend",
    "yaml",
    "yaml+jinja",
]
