TOKENS = [
    "Token.Keyword",
    "Token.Keyword.Constant",
    "Token.Keyword.Declaration",
    "Token.Keyword.Namespace",
    "Token.Keyword.Pseudo",
    "Token.Keyword.Reserved",
    "Token.Keyword.Type",
    "Token.Name",
    "Token.Name.Attribute",
    "Token.Name.Builtin",
    "Token.Name.Builtin.Pseudo",
    "Token.Name.Class",
    "Token.Name.Constant",
    "Token.Name.Decorator",
    "Token.Name.Entity",
    "Token.Name.Exception",
    "Token.Name.Function",
    "Token.Name.Function.Magic",
    "Token.Name.Label",
    "Token.Name.Namespace",
    "Token.Name.Other",
    "Token.Name.Tag",
    "Token.Name.Variable",
    "Token.Name.Variable.Class",
    "Token.Name.Variable.Global",
    "Token.Name.Variable.Instance",
    "Token.Name.Variable.Magic",
    "Token.Literal",
    "Token.Literal.Date",
    "Token.Literal.String",
    "Token.Literal.String.Affix",
    "Token.Literal.String.Backtick",
    "Token.Literal.String.Char",
    "Token.Literal.String.Delimiter",
    "Token.Literal.String.Doc",
    "Token.Literal.String.Double",
    "Token.Literal.String.Escape",
    "Token.Literal.String.Heredoc",
    "Token.Literal.String.Interpol",
    "Token.Literal.String.Other",
    "Token.Literal.String.Regex",
    "Token.Literal.String.Single",
    "Token.Literal.String.Symbol",
    "Token.Literal.Number",
    "Token.Literal.Number.Bin",
    "Token.Literal.Number.Float",
    "Token.Literal.Number.Hex",
    "Token.Literal.Number.Integer",
    "Token.Literal.Number.Integer.Long",
    "Token.Literal.Number.Oct",
    "Token.Operator",
    "Token.Operator.Word",
    "Token.Punctuation",
    "Token.Comment",
    "Token.Comment.Hashbang",
    "Token.Comment.Multiline",
    "Token.Comment.Preproc",
    "Token.Comment.Single",
    "Token.Comment.Special",
    "Token.Generic",
    "Token.Generic.Deleted",
    "Token.Generic.Emph",
    "Token.Generic.Error",
    "Token.Generic.Heading",
    "Token.Generic.Inserted",
    "Token.Generic.Output",
    "Token.Generic.Prompt",
    "Token.Generic.Strong",
    "Token.Generic.Subheading",
    "Token.Generic.Traceback",
    "Token.Text.Whitespace",
]
